import { Button, Form, Input } from "antd";
import React, { useContext } from "react"
import { QrcodeOutlined, UserOutlined } from "@ant-design/icons";
import CodeInput from "../../components/codeInput";
import { isMobile } from "../../utils";
import { useAjax } from "../../hooks/useAjax";
import { userLoginmApi } from "../../api";
import { setToken } from "../../utils/auth";
import { DispatchContext } from "../../App";


interface Props {
    type?: 'LOGIN' | 'REG'
}
/**
 * 手机号登录注册
 * @returns 
 */
const MRegPop: React.FC<Props> = ({ type = 'LOGIN' }) => {

    /**************************/
    const { dispatch, state: { initData: { h5LoginLogo: logo } } } = useContext(DispatchContext)!;
    const [form] = Form.useForm()
    const mobile = Form.useWatch('mobile', form)
    const userLoginm = useAjax((params) => userLoginmApi(params))
    /**************************/

    const onFinish = (values: any) => {
        userLoginm.run(values).then(res => {
            if (+res.code === 200) {
                dispatch({ type: 'setToken', params: { token: res?.data?.token } })
                setToken(res?.data?.token)
            }
        })
    };

    return <div className="pop">
        <div className="pop_body">
            <div className="login_head">
                <img className="login_logo" src={logo} />
                <span className="login_title">{type === 'LOGIN' ? '手机登录' : '手机注册'}</span>
            </div>
            <div className="login_body">
                <Form
                    name="basic"
                    form={form}
                    onFinish={onFinish}
                >
                    <Form.Item name="mobile" style={{ marginBottom: 10 }} rules={[
                        {
                            required: true,
                            validator(_rule, value) {
                                if (!value) {
                                    return Promise.reject(new Error('请输入手机号!'))
                                } else if (!isMobile(value)) {
                                    return Promise.reject(new Error('请输入正确的手机号!'))
                                }
                                return Promise.resolve()
                            }
                        }
                    ]}>
                        <Input prefix={<UserOutlined />} placeholder="请输入手机号" size="large" />
                    </Form.Item>
                    <Form.Item name="code" style={{ marginBottom: 20 }} rules={[{ required: true, message: '请输入验证码!' }]}>
                        <CodeInput mobile={mobile} msgType={1} prefix={<QrcodeOutlined />} placeholder="请输入验证码" size="large" />
                    </Form.Item>
                    <Form.Item style={{ marginBottom: 10 }}>
                        <Button type="primary" loading={userLoginm.loading} className="form_button" htmlType="submit" size="large">{type === 'LOGIN' ? '登录' : '注册'}</Button>
                    </Form.Item>
                </Form>
            </div>
            <div className="login_foot" style={{ justifyContent: 'space-between' }}>
                <Button type="text" style={{ padding: 0 }} onClick={() => dispatch({ type: 'setTypeSwitch', params: { typeSwitch: 'USER_LOGIN' } })}>返回登录</Button>
                <Button type="text" style={{ padding: 0 }} onClick={() => dispatch({ type: 'setTypeSwitch', params: { typeSwitch: 'USER_REG' } })}>账号注册</Button>
            </div>
        </div>
    </div>
}

export default React.memo(MRegPop)